@@ -1,5 +1,6 @@
+#![allow(dead_code)]
+
 use egui::{Event, Key, Modifiers, PointerButton, Pos2, RawInput, Rect, Vec2};
-use parking_lot::Mutex;
 use std::ffi::CStr;
 use windows::Win32::{
     Foundation::{HWND, RECT},
@@ -25,7 +26,7 @@ use windows::Win32::{
 
 pub struct InputCollector {
     hwnd: HWND,
-    events: Mutex<Vec<Event>>,
+    events: Vec<Event>,
 }
 
 /// High-level overview of recognized `WndProc` messages.
@@ -58,21 +59,18 @@ impl InputCollector {
     pub fn new(hwnd: HWND) -> Self {
         Self {
             hwnd,
-            events: Mutex::new(vec![]),
+            events: vec![],
         }
     }
 
-    pub fn process(&self, umsg: u32, wparam: usize, lparam: isize) -> InputResult {
+    pub fn process(&mut self, umsg: u32, wparam: usize, lparam: isize) -> InputResult {
         match umsg {
             WM_MOUSEMOVE => {
-                self
-                    .events
-                    .lock()
-                    .push(Event::PointerMoved(get_pos(lparam)));
+                self.events.push(Event::PointerMoved(get_pos(lparam)));
                 InputResult::MouseMove
             }
             WM_LBUTTONDOWN | WM_LBUTTONDBLCLK => {
-                self.events.lock().push(Event::PointerButton {
+                self.events.push(Event::PointerButton {
                     pos: get_pos(lparam),
                     button: PointerButton::Primary,
                     pressed: true,
@@ -81,7 +79,7 @@ impl InputCollector {
                 InputResult::MouseLeft
             }
             WM_LBUTTONUP => {
-                self.events.lock().push(Event::PointerButton {
+                self.events.push(Event::PointerButton {
                     pos: get_pos(lparam),
                     button: PointerButton::Primary,
                     pressed: false,
@@ -90,7 +88,7 @@ impl InputCollector {
                 InputResult::MouseLeft
             }
             WM_RBUTTONDOWN | WM_RBUTTONDBLCLK => {
-                self.events.lock().push(Event::PointerButton {
+                self.events.push(Event::PointerButton {
                     pos: get_pos(lparam),
                     button: PointerButton::Secondary,
                     pressed: true,
@@ -99,7 +97,7 @@ impl InputCollector {
                 InputResult::MouseRight
             }
             WM_RBUTTONUP => {
-                self.events.lock().push(Event::PointerButton {
+                self.events.push(Event::PointerButton {
                     pos: get_pos(lparam),
                     button: PointerButton::Secondary,
                     pressed: false,
@@ -108,7 +106,7 @@ impl InputCollector {
                 InputResult::MouseRight
             }
             WM_MBUTTONDOWN | WM_MBUTTONDBLCLK => {
-                self.events.lock().push(Event::PointerButton {
+                self.events.push(Event::PointerButton {
                     pos: get_pos(lparam),
                     button: PointerButton::Middle,
                     pressed: true,
@@ -117,7 +115,7 @@ impl InputCollector {
                 InputResult::MouseMiddle
             }
             WM_MBUTTONUP => {
-                self.events.lock().push(Event::PointerButton {
+                self.events.push(Event::PointerButton {
                     pos: get_pos(lparam),
                     button: PointerButton::Middle,
                     pressed: false,
@@ -125,62 +123,52 @@ impl InputCollector {
                 });
                 InputResult::MouseMiddle
             }
-            // TODO: Decide if adding `WM_SYSCHAR` is necessary.
-            WM_CHAR /* | WM_SYSCHAR */ => {
+            WM_CHAR => {
                 if let Some(ch) = char::from_u32(wparam as _) {
                     if !ch.is_control() {
-                        self.events.lock().push(Event::Text(ch.into()));
+                        self.events.push(Event::Text(ch.into()));
                     }
                 }
                 InputResult::Character
-            },
+            }
             WM_MOUSEWHEEL => {
                 let delta = (wparam >> 16) as i16 as f32 * 10. / WHEEL_DELTA as f32;
 
                 if wparam & MK_CONTROL as usize != 0 {
-                    self.events.lock().push(Event::Zoom(
-                        if delta > 0. { 1.5 } else { 0.5 }
-                    ));
+                    self.events
+                        .push(Event::Zoom(if delta > 0. { 1.5 } else { 0.5 }));
                     InputResult::Zoom
                 } else {
-                    self.events.lock().push(Event::Scroll(
-                        Vec2::new(0., delta)
-                    ));
+                    self.events.push(Event::Scroll(Vec2::new(0., delta)));
                     InputResult::Scroll
                 }
-            },
+            }
             WM_MOUSEHWHEEL => {
                 let delta = (wparam >> 16) as i16 as f32 * 10. / WHEEL_DELTA as f32;
 
                 if wparam & MK_CONTROL as usize != 0 {
-                    self.events.lock().push(Event::Zoom(
-                        if delta > 0. { 1.5 } else { 0.5 }
-                    ));
+                    self.events
+                        .push(Event::Zoom(if delta > 0. { 1.5 } else { 0.5 }));
                     InputResult::Zoom
                 } else {
-                    self.events.lock().push(Event::Scroll(
-                        Vec2::new(delta, 0.)
-                    ));
+                    self.events.push(Event::Scroll(Vec2::new(delta, 0.)));
                     InputResult::Scroll
                 }
-            },
+            }
             msg @ (WM_KEYDOWN | WM_SYSKEYDOWN) => {
                 if let Some(key) = get_key(wparam) {
-                    let lock = &mut *self.events.lock();
                     let mods = get_key_modifiers(msg);
 
-                    if key == Key::Space {
-                        lock.push(Event::Text(String::from(" ")));
-                    } else if key == Key::V && mods.ctrl {
+                    if key == Key::V && mods.ctrl {
                         if let Some(clipboard) = get_clipboard_text() {
-                            lock.push(Event::Text(clipboard));
+                            self.events.push(Event::Text(clipboard));
                         }
                     } else if key == Key::C && mods.ctrl {
-                        lock.push(Event::Copy);
+                        self.events.push(Event::Copy);
                     } else if key == Key::X && mods.ctrl {
-                        lock.push(Event::Cut);
+                        self.events.push(Event::Cut);
                     } else {
-                        lock.push(Event::Key {
+                        self.events.push(Event::Key {
                             key,
                             pressed: true,
                             modifiers: get_key_modifiers(msg),
@@ -188,30 +176,31 @@ impl InputCollector {
                     }
                 }
                 InputResult::Key
-            },
+            }
             msg @ (WM_KEYUP | WM_SYSKEYUP) => {
                 if let Some(key) = get_key(wparam) {
-                    self.events.lock().push(Event::Key {
+                    self.events.push(Event::Key {
                         key,
                         pressed: false,
                         modifiers: get_key_modifiers(msg),
                     });
                 }
                 InputResult::Key
-            },
-            _ => InputResult::Unknown
+            }
+            _ => InputResult::Unknown,
         }
     }
 
-    pub fn collect_input(&self) -> RawInput {
-        let events = std::mem::take(&mut *self.events.lock());
+    pub fn collect_input(&mut self) -> RawInput {
+        let events = std::mem::take(&mut self.events);
 
         RawInput {
             screen_rect: Some(self.get_screen_rect()),
             time: Some(Self::get_system_time()),
-            pixels_per_point: Some(1.),
-            predicted_dt: 1. / 60.,
             modifiers: Modifiers::default(),
+            pixels_per_point: Some(1.),
+            max_texture_side: None,
+            predicted_dt: 1. / 60.,
             hovered_files: vec![],
             dropped_files: vec![],
             events,
@@ -222,7 +211,7 @@ impl InputCollector {
     pub fn get_system_time() -> f64 {
         let mut time = 0;
         unsafe {
-            expect!(NtQuerySystemTime(&mut time), "Failed to get system time.");
+            expect!(NtQuerySystemTime(&mut time), "Failed to get system time");
         }
 
         // dumb ass, read the docs. egui clearly says `in seconds`.
@@ -312,12 +301,14 @@ fn get_key(wparam: usize) -> Option<Key> {
 fn get_clipboard_text() -> Option<String> {
     unsafe {
         if OpenClipboard(HWND::default()).as_bool() {
-            let txt = GetClipboardData(CF_TEXT.0).0 as *const i8;
-            let data = Some(CStr::from_ptr(txt).to_str().ok()?.to_string());
-            CloseClipboard();
-            data
-        } else {
-            None
+            let txt = GetClipboardData(CF_TEXT.0).ok()?.0 as *const i8;
+            if !txt.is_null() {
+                let data = Some(CStr::from_ptr(txt).to_str().ok()?.to_string());
+                CloseClipboard();
+                return data;
+            }
         }
+
+        None
     }
 }
