@@ -9,20 +9,30 @@ macro_rules! expect {
     };
 }
 
+macro_rules! panic_msg {
+    ($($t:tt)*) => {
+        if cfg!(feature = "no-msgs") {
+            unimplemented!()
+        } else {
+            panic!($($t)*)
+        }
+    };
+}
+
 /// Creates zero terminated string.
-macro_rules! c_str {
+macro_rules! pc_str {
     ($cstr:expr) => {
-        windows::Win32::Foundation::PSTR(concat!($cstr, "\x00").as_ptr() as _)
+        windows::core::PCSTR(concat!($cstr, "\x00").as_ptr() as _)
     };
 }
 
 mod app;
 pub use app::*;
 
-mod input;
-pub use input::InputResult;
-
 mod backup;
+mod input;
 mod mesh;
 mod shader;
 mod texture;
+
+pub use input::InputResult;
